@@ -19,7 +19,7 @@ our @EXPORT_OK = qw(untied %DEFAULT_BEHAVIOR);
 our %DEFAULT_BEHAVIOR;
 *DEFAULT_BEHAVIOR = \%Signals::XSIG::Default::DEFAULT_BEHAVIOR;
 
-our $VERSION = '0.15_03';
+our $VERSION = '0.15_04';
 our (%XSIG, %_XSIG, %SIGTABLE, $_REFRESH, $_DISABLE_WARNINGS);
 our $_INITIALIZED = 0;
 our $SIGTIE = bless {}, 'Signals::XSIG::TieSIG';
@@ -32,8 +32,8 @@ my %alias = ();
 
 ###
 # to be removed when we get a handle on intermittent t/02 failures
-our ($XDEBUG,@XLOG) = (0);
-sub XLOG{no warnings"uninitialized";push @XLOG,(Time::HiRes::time-$^T)." @_"}
+our ($XDEBUG,$XN,@XLOG) = (0,1001);
+sub XLOG{no warnings"uninitialized";push @XLOG,($XN++)." @_"}
 sub XLOG_DUMP{join"\n",@XLOG}
 ###
 
@@ -306,14 +306,19 @@ sub Signals::XSIG::TieSIG::CLEAR {
         XLOG("    CLEAR init USR2=",@{$_XSIG{USR2}});
     };
 
-    # $_XSIG{$_} is tied to 'Signals::XSIG::TieScalar'
-    # @{$_XSIG{$_}} is tied to 'Signals::XSIG::TieArray'
-    #     a tied array gives us:
-    #     1. negative indices, used appropriately
-    #     2. immediate update to the real signal handler
-    # $_XSIG{$_}[0] is equiv to
-    #     Signals::XSIG::TieArray::STORE( tied(@{$_XSIG{$_}}, 0, undef) )
-    $_XSIG{$_}[0] = undef for keys %_XSIG;
+    # this used to say
+    #     $_XSIG{$_}[0] = undef for keys %_XSIG
+    # but on some platforms, for a reason I don't yet understand,
+    # the signal handler for the first value in the for loop
+    # would not get cleared properly. For another reason I don't
+    # yet understand, this is apparently not an issue for the
+    # __WARN__ and __DIE__ handlers, so we'll manipulate the signal
+    # list to make sure those handlers go first.
+    
+    my @sigs = reverse sort keys %_XSIG;
+    $XDEBUG && XLOG("    \@sigs = qw(@sigs);");
+    $_XSIG{$_}[0] = undef for @sigs;
+
     $XDEBUG && do {
         XLOG("    CLEAR final USR1=",@{$_XSIG{USR1}});
         XLOG("    CLEAR final USR2=",@{$_XSIG{USR2}});
@@ -662,7 +667,7 @@ Signals::XSIG - install multiple signal handlers through %XSIG
 
 =head1 VERSION
 
-Version 0.15_03
+Version 0.15_04
 
 =head1 SYNOPSIS
 
